# Copyright (C) 2022 The Qt Company Ltd.
# SPDX-License-Identifier: LicenseRef-Qt-Commercial OR LGPL-3.0-only OR GPL-2.0-only OR GPL-3.0-only
from __future__ import annotations

"""
This file contains the exact signatures for all functions in module
PySide6.QtOpenGL, except for defaults which are replaced by "...".
"""

# Module `PySide6.QtOpenGL`

import PySide6.QtOpenGL
import PySide6.QtCore
import PySide6.QtGui

import enum
from typing import Any, ClassVar, List, Optional, Sequence, Tuple, Union, overload
from PySide6.QtCore import Signal
from shiboken6 import Shiboken


NoneType = type(None)


class QAbstractOpenGLFunctions(Shiboken.Object):

    def __init__(self) -> None: ...

    def initializeOpenGLFunctions(self) -> bool: ...
    def isInitialized(self) -> bool: ...
    def owningContext(self) -> PySide6.QtGui.QOpenGLContext: ...
    def setOwningContext(self, context: PySide6.QtGui.QOpenGLContext) -> None: ...


class QIntList(object): ...


class QOpenGLBuffer(Shiboken.Object):

    class Access(enum.Enum):

        ReadOnly                 : QOpenGLBuffer.Access = ... # 0x88b8
        WriteOnly                : QOpenGLBuffer.Access = ... # 0x88b9
        ReadWrite                : QOpenGLBuffer.Access = ... # 0x88ba

    class RangeAccessFlag(enum.Flag):

        RangeRead                : QOpenGLBuffer.RangeAccessFlag = ... # 0x1
        RangeWrite               : QOpenGLBuffer.RangeAccessFlag = ... # 0x2
        RangeInvalidate          : QOpenGLBuffer.RangeAccessFlag = ... # 0x4
        RangeInvalidateBuffer    : QOpenGLBuffer.RangeAccessFlag = ... # 0x8
        RangeFlushExplicit       : QOpenGLBuffer.RangeAccessFlag = ... # 0x10
        RangeUnsynchronized      : QOpenGLBuffer.RangeAccessFlag = ... # 0x20

    class Type(enum.Enum):

        VertexBuffer             : QOpenGLBuffer.Type = ... # 0x8892
        IndexBuffer              : QOpenGLBuffer.Type = ... # 0x8893
        PixelPackBuffer          : QOpenGLBuffer.Type = ... # 0x88eb
        PixelUnpackBuffer        : QOpenGLBuffer.Type = ... # 0x88ec

    class UsagePattern(enum.Enum):

        StreamDraw               : QOpenGLBuffer.UsagePattern = ... # 0x88e0
        StreamRead               : QOpenGLBuffer.UsagePattern = ... # 0x88e1
        StreamCopy               : QOpenGLBuffer.UsagePattern = ... # 0x88e2
        StaticDraw               : QOpenGLBuffer.UsagePattern = ... # 0x88e4
        StaticRead               : QOpenGLBuffer.UsagePattern = ... # 0x88e5
        StaticCopy               : QOpenGLBuffer.UsagePattern = ... # 0x88e6
        DynamicDraw              : QOpenGLBuffer.UsagePattern = ... # 0x88e8
        DynamicRead              : QOpenGLBuffer.UsagePattern = ... # 0x88e9
        DynamicCopy              : QOpenGLBuffer.UsagePattern = ... # 0x88ea


    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: PySide6.QtOpenGL.QOpenGLBuffer) -> None: ...
    @overload
    def __init__(self, type: PySide6.QtOpenGL.QOpenGLBuffer.Type) -> None: ...

    @overload
    def allocate(self, count: int) -> None: ...
    @overload
    def allocate(self, data: bytes, count: int) -> None: ...
    def bind(self) -> bool: ...
    def bufferId(self) -> int: ...
    def create(self) -> bool: ...
    def destroy(self) -> None: ...
    def isCreated(self) -> bool: ...
    def map(self, access: PySide6.QtOpenGL.QOpenGLBuffer.Access) -> int: ...
    def mapRange(self, offset: int, count: int, access: PySide6.QtOpenGL.QOpenGLBuffer.RangeAccessFlag) -> int: ...
    def read(self, offset: int, data: int, count: int) -> bool: ...
    @overload
    def release(self) -> None: ...
    @overload
    @staticmethod
    def release(type: PySide6.QtOpenGL.QOpenGLBuffer.Type) -> None: ...
    def setUsagePattern(self, value: PySide6.QtOpenGL.QOpenGLBuffer.UsagePattern) -> None: ...
    def size(self) -> int: ...
    def swap(self, other: PySide6.QtOpenGL.QOpenGLBuffer) -> None: ...
    def type(self) -> PySide6.QtOpenGL.QOpenGLBuffer.Type: ...
    def unmap(self) -> bool: ...
    def usagePattern(self) -> PySide6.QtOpenGL.QOpenGLBuffer.UsagePattern: ...
    def write(self, offset: int, data: int, count: int) -> None: ...


class QOpenGLDebugLogger(PySide6.QtCore.QObject):

    messageLogged            : ClassVar[Signal] = ... # messageLogged(QOpenGLDebugMessage)

    class LoggingMode(enum.Enum):

        AsynchronousLogging      : QOpenGLDebugLogger.LoggingMode = ... # 0x0
        SynchronousLogging       : QOpenGLDebugLogger.LoggingMode = ... # 0x1


    def __init__(self, parent: Optional[PySide6.QtCore.QObject] = ...) -> None: ...

    @overload
    def disableMessages(self, ids: Sequence[int], sources: PySide6.QtOpenGL.QOpenGLDebugMessage.Source = ..., types: PySide6.QtOpenGL.QOpenGLDebugMessage.Type = ...) -> None: ...
    @overload
    def disableMessages(self, sources: PySide6.QtOpenGL.QOpenGLDebugMessage.Source = ..., types: PySide6.QtOpenGL.QOpenGLDebugMessage.Type = ..., severities: PySide6.QtOpenGL.QOpenGLDebugMessage.Severity = ...) -> None: ...
    @overload
    def enableMessages(self, ids: Sequence[int], sources: PySide6.QtOpenGL.QOpenGLDebugMessage.Source = ..., types: PySide6.QtOpenGL.QOpenGLDebugMessage.Type = ...) -> None: ...
    @overload
    def enableMessages(self, sources: PySide6.QtOpenGL.QOpenGLDebugMessage.Source = ..., types: PySide6.QtOpenGL.QOpenGLDebugMessage.Type = ..., severities: PySide6.QtOpenGL.QOpenGLDebugMessage.Severity = ...) -> None: ...
    def initialize(self) -> bool: ...
    def isLogging(self) -> bool: ...
    def logMessage(self, debugMessage: PySide6.QtOpenGL.QOpenGLDebugMessage) -> None: ...
    def loggedMessages(self) -> List[PySide6.QtOpenGL.QOpenGLDebugMessage]: ...
    def loggingMode(self) -> PySide6.QtOpenGL.QOpenGLDebugLogger.LoggingMode: ...
    def maximumMessageLength(self) -> int: ...
    def popGroup(self) -> None: ...
    def pushGroup(self, name: str, id: int = ..., source: PySide6.QtOpenGL.QOpenGLDebugMessage.Source = ...) -> None: ...
    def startLogging(self, loggingMode: PySide6.QtOpenGL.QOpenGLDebugLogger.LoggingMode = ...) -> None: ...
    def stopLogging(self) -> None: ...


class QOpenGLDebugMessage(Shiboken.Object):

    class Severity(enum.Flag):

        InvalidSeverity          : QOpenGLDebugMessage.Severity = ... # 0x0
        HighSeverity             : QOpenGLDebugMessage.Severity = ... # 0x1
        MediumSeverity           : QOpenGLDebugMessage.Severity = ... # 0x2
        LowSeverity              : QOpenGLDebugMessage.Severity = ... # 0x4
        LastSeverity             : QOpenGLDebugMessage.Severity = ... # 0x8
        NotificationSeverity     : QOpenGLDebugMessage.Severity = ... # 0x8
        AnySeverity              : QOpenGLDebugMessage.Severity = ... # 0xffffffff

    class Source(enum.Flag):

        InvalidSource            : QOpenGLDebugMessage.Source = ... # 0x0
        APISource                : QOpenGLDebugMessage.Source = ... # 0x1
        WindowSystemSource       : QOpenGLDebugMessage.Source = ... # 0x2
        ShaderCompilerSource     : QOpenGLDebugMessage.Source = ... # 0x4
        ThirdPartySource         : QOpenGLDebugMessage.Source = ... # 0x8
        ApplicationSource        : QOpenGLDebugMessage.Source = ... # 0x10
        LastSource               : QOpenGLDebugMessage.Source = ... # 0x20
        OtherSource              : QOpenGLDebugMessage.Source = ... # 0x20
        AnySource                : QOpenGLDebugMessage.Source = ... # 0xffffffff

    class Type(enum.Flag):

        InvalidType              : QOpenGLDebugMessage.Type = ... # 0x0
        ErrorType                : QOpenGLDebugMessage.Type = ... # 0x1
        DeprecatedBehaviorType   : QOpenGLDebugMessage.Type = ... # 0x2
        UndefinedBehaviorType    : QOpenGLDebugMessage.Type = ... # 0x4
        PortabilityType          : QOpenGLDebugMessage.Type = ... # 0x8
        PerformanceType          : QOpenGLDebugMessage.Type = ... # 0x10
        OtherType                : QOpenGLDebugMessage.Type = ... # 0x20
        MarkerType               : QOpenGLDebugMessage.Type = ... # 0x40
        GroupPushType            : QOpenGLDebugMessage.Type = ... # 0x80
        GroupPopType             : QOpenGLDebugMessage.Type = ... # 0x100
        LastType                 : QOpenGLDebugMessage.Type = ... # 0x100
        AnyType                  : QOpenGLDebugMessage.Type = ... # 0xffffffff


    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, debugMessage: PySide6.QtOpenGL.QOpenGLDebugMessage) -> None: ...

    @staticmethod
    def __copy__() -> None: ...
    @staticmethod
    def createApplicationMessage(text: str, id: int = ..., severity: PySide6.QtOpenGL.QOpenGLDebugMessage.Severity = ..., type: PySide6.QtOpenGL.QOpenGLDebugMessage.Type = ...) -> PySide6.QtOpenGL.QOpenGLDebugMessage: ...
    @staticmethod
    def createThirdPartyMessage(text: str, id: int = ..., severity: PySide6.QtOpenGL.QOpenGLDebugMessage.Severity = ..., type: PySide6.QtOpenGL.QOpenGLDebugMessage.Type = ...) -> PySide6.QtOpenGL.QOpenGLDebugMessage: ...
    def id(self) -> int: ...
    def message(self) -> str: ...
    def severity(self) -> PySide6.QtOpenGL.QOpenGLDebugMessage.Severity: ...
    def source(self) -> PySide6.QtOpenGL.QOpenGLDebugMessage.Source: ...
    def swap(self, other: PySide6.QtOpenGL.QOpenGLDebugMessage) -> None: ...
    def type(self) -> PySide6.QtOpenGL.QOpenGLDebugMessage.Type: ...


class QOpenGLFramebufferObject(Shiboken.Object):

    class Attachment(enum.Enum):

        NoAttachment             : QOpenGLFramebufferObject.Attachment = ... # 0x0
        CombinedDepthStencil     : QOpenGLFramebufferObject.Attachment = ... # 0x1
        Depth                    : QOpenGLFramebufferObject.Attachment = ... # 0x2

    class FramebufferRestorePolicy(enum.Enum):

        DontRestoreFramebufferBinding: QOpenGLFramebufferObject.FramebufferRestorePolicy = ... # 0x0
        RestoreFramebufferBindingToDefault: QOpenGLFramebufferObject.FramebufferRestorePolicy = ... # 0x1
        RestoreFrameBufferBinding: QOpenGLFramebufferObject.FramebufferRestorePolicy = ... # 0x2


    @overload
    def __init__(self, size: PySide6.QtCore.QSize, attachment: PySide6.QtOpenGL.QOpenGLFramebufferObject.Attachment, target: int = ..., internalFormat: int = ...) -> None: ...
    @overload
    def __init__(self, size: PySide6.QtCore.QSize, format: PySide6.QtOpenGL.QOpenGLFramebufferObjectFormat) -> None: ...
    @overload
    def __init__(self, size: PySide6.QtCore.QSize, target: int = ...) -> None: ...
    @overload
    def __init__(self, width: int, height: int, attachment: PySide6.QtOpenGL.QOpenGLFramebufferObject.Attachment, target: int = ..., internalFormat: int = ...) -> None: ...
    @overload
    def __init__(self, width: int, height: int, format: PySide6.QtOpenGL.QOpenGLFramebufferObjectFormat) -> None: ...
    @overload
    def __init__(self, width: int, height: int, target: int = ...) -> None: ...

    @overload
    def addColorAttachment(self, size: PySide6.QtCore.QSize, internalFormat: int = ...) -> None: ...
    @overload
    def addColorAttachment(self, width: int, height: int, internalFormat: int = ...) -> None: ...
    def attachment(self) -> PySide6.QtOpenGL.QOpenGLFramebufferObject.Attachment: ...
    def bind(self) -> bool: ...
    @staticmethod
    def bindDefault() -> bool: ...
    @overload
    @staticmethod
    def blitFramebuffer(target: PySide6.QtOpenGL.QOpenGLFramebufferObject, source: PySide6.QtOpenGL.QOpenGLFramebufferObject, buffers: int = ..., filter: int = ...) -> None: ...
    @overload
    @staticmethod
    def blitFramebuffer(target: PySide6.QtOpenGL.QOpenGLFramebufferObject, targetRect: PySide6.QtCore.QRect, source: PySide6.QtOpenGL.QOpenGLFramebufferObject, sourceRect: PySide6.QtCore.QRect, buffers: int, filter: int, readColorAttachmentIndex: int, drawColorAttachmentIndex: int) -> None: ...
    @overload
    @staticmethod
    def blitFramebuffer(target: PySide6.QtOpenGL.QOpenGLFramebufferObject, targetRect: PySide6.QtCore.QRect, source: PySide6.QtOpenGL.QOpenGLFramebufferObject, sourceRect: PySide6.QtCore.QRect, buffers: int, filter: int, readColorAttachmentIndex: int, drawColorAttachmentIndex: int, restorePolicy: PySide6.QtOpenGL.QOpenGLFramebufferObject.FramebufferRestorePolicy) -> None: ...
    @overload
    @staticmethod
    def blitFramebuffer(target: PySide6.QtOpenGL.QOpenGLFramebufferObject, targetRect: PySide6.QtCore.QRect, source: PySide6.QtOpenGL.QOpenGLFramebufferObject, sourceRect: PySide6.QtCore.QRect, buffers: int = ..., filter: int = ...) -> None: ...
    def format(self) -> PySide6.QtOpenGL.QOpenGLFramebufferObjectFormat: ...
    def handle(self) -> int: ...
    @staticmethod
    def hasOpenGLFramebufferBlit() -> bool: ...
    @staticmethod
    def hasOpenGLFramebufferObjects() -> bool: ...
    def height(self) -> int: ...
    def isBound(self) -> bool: ...
    def isValid(self) -> bool: ...
    def release(self) -> bool: ...
    def setAttachment(self, attachment: PySide6.QtOpenGL.QOpenGLFramebufferObject.Attachment) -> None: ...
    def size(self) -> PySide6.QtCore.QSize: ...
    def sizes(self) -> List[PySide6.QtCore.QSize]: ...
    @overload
    def takeTexture(self) -> int: ...
    @overload
    def takeTexture(self, colorAttachmentIndex: int) -> int: ...
    def texture(self) -> int: ...
    def textures(self) -> List[int]: ...
    @overload
    def toImage(self, flipped: bool, colorAttachmentIndex: int) -> PySide6.QtGui.QImage: ...
    @overload
    def toImage(self, flipped: bool = ...) -> PySide6.QtGui.QImage: ...
    def width(self) -> int: ...


class QOpenGLFramebufferObjectFormat(Shiboken.Object):

    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, other: PySide6.QtOpenGL.QOpenGLFramebufferObjectFormat) -> None: ...

    @staticmethod
    def __copy__() -> None: ...
    def attachment(self) -> PySide6.QtOpenGL.QOpenGLFramebufferObject.Attachment: ...
    def internalTextureFormat(self) -> int: ...
    def mipmap(self) -> bool: ...
    def samples(self) -> int: ...
    def setAttachment(self, attachment: PySide6.QtOpenGL.QOpenGLFramebufferObject.Attachment) -> None: ...
    def setInternalTextureFormat(self, internalTextureFormat: int) -> None: ...
    def setMipmap(self, enabled: bool) -> None: ...
    def setSamples(self, samples: int) -> None: ...
    def setTextureTarget(self, target: int) -> None: ...
    def textureTarget(self) -> int: ...


class QOpenGLFunctions_ES2(PySide6.QtOpenGL.QAbstractOpenGLFunctions):

    def __init__(self) -> None: ...

    def glActiveTexture(self, texture: int) -> None: ...
    def glAttachShader(self, program: int, shader: int) -> None: ...
    def glBindAttribLocation(self, program: int, index: int, name: Union[bytes, bytearray, memoryview]) -> None: ...
    def glBindBuffer(self, target: int, buffer: int) -> None: ...
    def glBindFramebuffer(self, target: int, framebuffer: int) -> None: ...
    def glBindRenderbuffer(self, target: int, renderbuffer: int) -> None: ...
    def glBindTexture(self, target: int, texture: int) -> None: ...
    def glBlendEquation(self, mode: int) -> None: ...
    def glBlendEquationSeparate(self, modeRGB: int, modeAlpha: int) -> None: ...
    def glBlendFunc(self, sfactor: int, dfactor: int) -> None: ...
    def glBlendFuncSeparate(self, srcRGB: int, dstRGB: int, srcAlpha: int, dstAlpha: int) -> None: ...
    def glCheckFramebufferStatus(self, target: int) -> int: ...
    def glClear(self, mask: int) -> None: ...
    def glClearStencil(self, s: int) -> None: ...
    def glColorMask(self, red: int, green: int, blue: int, alpha: int) -> None: ...
    def glCompileShader(self, shader: int) -> None: ...
    def glCompressedTexImage2D(self, target: int, level: int, internalformat: int, width: int, height: int, border: int, imageSize: int, data: int) -> None: ...
    def glCompressedTexSubImage2D(self, target: int, level: int, xoffset: int, yoffset: int, width: int, height: int, format: int, imageSize: int, data: int) -> None: ...
    def glCopyTexImage2D(self, target: int, level: int, internalformat: int, x: int, y: int, width: int, height: int, border: int) -> None: ...
    def glCopyTexSubImage2D(self, target: int, level: int, xoffset: int, yoffset: int, x: int, y: int, width: int, height: int) -> None: ...
    def glCreateProgram(self) -> int: ...
    def glCreateShader(self, type: int) -> int: ...
    def glCullFace(self, mode: int) -> None: ...
    def glDeleteBuffers(self, n: int, buffers: Sequence[int]) -> None: ...
    def glDeleteFramebuffers(self, n: int, framebuffers: Sequence[int]) -> None: ...
    def glDeleteProgram(self, program: int) -> None: ...
    def glDeleteRenderbuffers(self, n: int, renderbuffers: Sequence[int]) -> None: ...
    def glDeleteShader(self, shader: int) -> None: ...
    def glDeleteTextures(self, n: int, textures: Sequence[int]) -> None: ...
    def glDepthFunc(self, func: int) -> None: ...
    def glDepthMask(self, flag: int) -> None: ...
    def glDetachShader(self, program: int, shader: int) -> None: ...
    def glDisable(self, cap: int) -> None: ...
    def glDisableVertexAttribArray(self, index: int) -> None: ...
    def glDrawArrays(self, mode: int, first: int, count: int) -> None: ...
    def glDrawElements(self, mode: int, count: int, type: int, indices: int) -> None: ...
    def glEnable(self, cap: int) -> None: ...
    def glEnableVertexAttribArray(self, index: int) -> None: ...
    def glFinish(self) -> None: ...
    def glFlush(self) -> None: ...
    def glFramebufferRenderbuffer(self, target: int, attachment: int, renderbuffertarget: int, renderbuffer: int) -> None: ...
    def glFramebufferTexture2D(self, target: int, attachment: int, textarget: int, texture: int, level: int) -> None: ...
    def glFrontFace(self, mode: int) -> None: ...
    def glGenBuffers(self, n: int) -> int: ...
    def glGenFramebuffers(self, n: int) -> int: ...
    def glGenRenderbuffers(self, n: int) -> int: ...
    def glGenTextures(self, n: int) -> int: ...
    def glGenerateMipmap(self, target: int) -> None: ...
    def glGetAttachedShaders(self, program: int, maxcount: int) -> Tuple[int, int]: ...
    def glGetAttribLocation(self, program: int, name: Union[bytes, bytearray, memoryview]) -> int: ...
    def glGetBooleanv(self, pname: int, params: Union[bytes, bytearray, memoryview]) -> None: ...
    def glGetBufferParameteriv(self, target: int, pname: int) -> int: ...
    def glGetError(self) -> int: ...
    def glGetFramebufferAttachmentParameteriv(self, target: int, attachment: int, pname: int) -> int: ...
    def glGetIntegerv(self, pname: int) -> int: ...
    def glGetProgramiv(self, program: int, pname: int) -> int: ...
    def glGetRenderbufferParameteriv(self, target: int, pname: int) -> int: ...
    def glGetShaderPrecisionFormat(self, shadertype: int, precisiontype: int) -> Tuple[int, int]: ...
    def glGetShaderiv(self, shader: int, pname: int) -> int: ...
    def glGetTexParameteriv(self, target: int, pname: int) -> int: ...
    def glGetUniformLocation(self, program: int, name: Union[bytes, bytearray, memoryview]) -> int: ...
    def glGetUniformiv(self, program: int, location: int) -> int: ...
    def glGetVertexAttribiv(self, index: int, pname: int) -> int: ...
    def glHint(self, target: int, mode: int) -> None: ...
    def glIsBuffer(self, buffer: int) -> int: ...
    def glIsEnabled(self, cap: int) -> int: ...
    def glIsFramebuffer(self, framebuffer: int) -> int: ...
    def glIsProgram(self, program: int) -> int: ...
    def glIsRenderbuffer(self, renderbuffer: int) -> int: ...
    def glIsShader(self, shader: int) -> int: ...
    def glIsTexture(self, texture: int) -> int: ...
    def glLinkProgram(self, program: int) -> None: ...
    def glPixelStorei(self, pname: int, param: int) -> None: ...
    def glReadPixels(self, x: int, y: int, width: int, height: int, format: int, type: int, pixels: int) -> None: ...
    def glReleaseShaderCompiler(self) -> None: ...
    def glRenderbufferStorage(self, target: int, internalformat: int, width: int, height: int) -> None: ...
    def glScissor(self, x: int, y: int, width: int, height: int) -> None: ...
    def glShaderBinary(self, n: int, binaryformat: int, binary: int, length: int) -> int: ...
    def glStencilFunc(self, func: int, ref: int, mask: int) -> None: ...
    def glStencilFuncSeparate(self, face: int, func: int, ref: int, mask: int) -> None: ...
    def glStencilMask(self, mask: int) -> None: ...
    def glStencilMaskSeparate(self, face: int, mask: int) -> None: ...
    def glStencilOp(self, fail: int, zfail: int, zpass: int) -> None: ...
    def glStencilOpSeparate(self, face: int, fail: int, zfail: int, zpass: int) -> None: ...
    def glTexImage2D(self, target: int, level: int, internalformat: int, width: int, height: int, border: int, format: int, type: int, pixels: int) -> None: ...
    def glTexParameteri(self, target: int, pname: int, param: int) -> None: ...
    def glTexParameteriv(self, target: int, pname: int, params: Sequence[int]) -> None: ...
    def glTexSubImage2D(self, target: int, level: int, xoffset: int, yoffset: int, width: int, height: int, format: int, type: int, pixels: int) -> None: ...
    def glUniform1i(self, location: int, x: int) -> None: ...
    def glUniform1iv(self, location: int, count: int) -> int: ...
    def glUniform2i(self, location: int, x: int, y: int) -> None: ...
    def glUniform2iv(self, location: int, count: int) -> int: ...
    def glUniform3i(self, location: int, x: int, y: int, z: int) -> None: ...
    def glUniform3iv(self, location: int, count: int) -> int: ...
    def glUniform4i(self, location: int, x: int, y: int, z: int, w: int) -> None: ...
    def glUniform4iv(self, location: int, count: int) -> int: ...
    def glUseProgram(self, program: int) -> None: ...
    def glValidateProgram(self, program: int) -> None: ...
    def glVertexAttribPointer(self, indx: int, size: int, type: int, normalized: int, stride: int, ptr: int) -> None: ...
    def glViewport(self, x: int, y: int, width: int, height: int) -> None: ...
    def initializeOpenGLFunctions(self) -> bool: ...


class QOpenGLPaintDevice(PySide6.QtGui.QPaintDevice):

    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, size: PySide6.QtCore.QSize) -> None: ...
    @overload
    def __init__(self, width: int, height: int) -> None: ...

    def context(self) -> PySide6.QtGui.QOpenGLContext: ...
    def devType(self) -> int: ...
    def dotsPerMeterX(self) -> float: ...
    def dotsPerMeterY(self) -> float: ...
    def ensureActiveTarget(self) -> None: ...
    def metric(self, metric: PySide6.QtGui.QPaintDevice.PaintDeviceMetric) -> int: ...
    def paintEngine(self) -> PySide6.QtGui.QPaintEngine: ...
    def paintFlipped(self) -> bool: ...
    def setDevicePixelRatio(self, devicePixelRatio: float) -> None: ...
    def setDotsPerMeterX(self, arg__1: float) -> None: ...
    def setDotsPerMeterY(self, arg__1: float) -> None: ...
    def setPaintFlipped(self, flipped: bool) -> None: ...
    def setSize(self, size: PySide6.QtCore.QSize) -> None: ...
    def size(self) -> PySide6.QtCore.QSize: ...


class QOpenGLPixelTransferOptions(Shiboken.Object):

    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, arg__1: PySide6.QtOpenGL.QOpenGLPixelTransferOptions) -> None: ...

    @staticmethod
    def __copy__() -> None: ...
    def alignment(self) -> int: ...
    def imageHeight(self) -> int: ...
    def isLeastSignificantBitFirst(self) -> bool: ...
    def isSwapBytesEnabled(self) -> bool: ...
    def rowLength(self) -> int: ...
    def setAlignment(self, alignment: int) -> None: ...
    def setImageHeight(self, imageHeight: int) -> None: ...
    def setLeastSignificantByteFirst(self, lsbFirst: bool) -> None: ...
    def setRowLength(self, rowLength: int) -> None: ...
    def setSkipImages(self, skipImages: int) -> None: ...
    def setSkipPixels(self, skipPixels: int) -> None: ...
    def setSkipRows(self, skipRows: int) -> None: ...
    def setSwapBytesEnabled(self, swapBytes: bool) -> None: ...
    def skipImages(self) -> int: ...
    def skipPixels(self) -> int: ...
    def skipRows(self) -> int: ...
    def swap(self, other: PySide6.QtOpenGL.QOpenGLPixelTransferOptions) -> None: ...


class QOpenGLShader(PySide6.QtCore.QObject):

    class ShaderTypeBit(enum.Flag):

        Vertex                   : QOpenGLShader.ShaderTypeBit = ... # 0x1
        Fragment                 : QOpenGLShader.ShaderTypeBit = ... # 0x2
        Geometry                 : QOpenGLShader.ShaderTypeBit = ... # 0x4
        TessellationControl      : QOpenGLShader.ShaderTypeBit = ... # 0x8
        TessellationEvaluation   : QOpenGLShader.ShaderTypeBit = ... # 0x10
        Compute                  : QOpenGLShader.ShaderTypeBit = ... # 0x20


    def __init__(self, type: PySide6.QtOpenGL.QOpenGLShader.ShaderTypeBit, parent: Optional[PySide6.QtCore.QObject] = ...) -> None: ...

    @overload
    def compileSourceCode(self, source: str) -> bool: ...
    @overload
    def compileSourceCode(self, source: Union[bytes, bytearray, memoryview]) -> bool: ...
    @overload
    def compileSourceCode(self, source: Union[PySide6.QtCore.QByteArray, bytes, bytearray, memoryview]) -> bool: ...
    def compileSourceFile(self, fileName: str) -> bool: ...
    @staticmethod
    def hasOpenGLShaders(type: PySide6.QtOpenGL.QOpenGLShader.ShaderTypeBit, context: Optional[PySide6.QtGui.QOpenGLContext] = ...) -> bool: ...
    def isCompiled(self) -> bool: ...
    def log(self) -> str: ...
    def shaderId(self) -> int: ...
    def shaderType(self) -> PySide6.QtOpenGL.QOpenGLShader.ShaderTypeBit: ...
    def sourceCode(self) -> PySide6.QtCore.QByteArray: ...


class QOpenGLShaderProgram(PySide6.QtCore.QObject):

    def __init__(self, parent: Optional[PySide6.QtCore.QObject] = ...) -> None: ...

    @overload
    def addCacheableShaderFromSourceCode(self, type: PySide6.QtOpenGL.QOpenGLShader.ShaderTypeBit, source: str) -> bool: ...
    @overload
    def addCacheableShaderFromSourceCode(self, type: PySide6.QtOpenGL.QOpenGLShader.ShaderTypeBit, source: Union[bytes, bytearray, memoryview]) -> bool: ...
    @overload
    def addCacheableShaderFromSourceCode(self, type: PySide6.QtOpenGL.QOpenGLShader.ShaderTypeBit, source: Union[PySide6.QtCore.QByteArray, bytes, bytearray, memoryview]) -> bool: ...
    def addCacheableShaderFromSourceFile(self, type: PySide6.QtOpenGL.QOpenGLShader.ShaderTypeBit, fileName: str) -> bool: ...
    def addShader(self, shader: PySide6.QtOpenGL.QOpenGLShader) -> bool: ...
    @overload
    def addShaderFromSourceCode(self, type: PySide6.QtOpenGL.QOpenGLShader.ShaderTypeBit, source: str) -> bool: ...
    @overload
    def addShaderFromSourceCode(self, type: PySide6.QtOpenGL.QOpenGLShader.ShaderTypeBit, source: Union[bytes, bytearray, memoryview]) -> bool: ...
    @overload
    def addShaderFromSourceCode(self, type: PySide6.QtOpenGL.QOpenGLShader.ShaderTypeBit, source: Union[PySide6.QtCore.QByteArray, bytes, bytearray, memoryview]) -> bool: ...
    def addShaderFromSourceFile(self, type: PySide6.QtOpenGL.QOpenGLShader.ShaderTypeBit, fileName: str) -> bool: ...
    @overload
    def attributeLocation(self, name: str) -> int: ...
    @overload
    def attributeLocation(self, name: Union[bytes, bytearray, memoryview]) -> int: ...
    @overload
    def attributeLocation(self, name: Union[PySide6.QtCore.QByteArray, bytes, bytearray, memoryview]) -> int: ...
    def bind(self) -> bool: ...
    @overload
    def bindAttributeLocation(self, name: str, location: int) -> None: ...
    @overload
    def bindAttributeLocation(self, name: Union[bytes, bytearray, memoryview], location: int) -> None: ...
    @overload
    def bindAttributeLocation(self, name: Union[PySide6.QtCore.QByteArray, bytes, bytearray, memoryview], location: int) -> None: ...
    def create(self) -> bool: ...
    def defaultInnerTessellationLevels(self) -> List[float]: ...
    def defaultOuterTessellationLevels(self) -> List[float]: ...
    @overload
    def disableAttributeArray(self, location: int) -> None: ...
    @overload
    def disableAttributeArray(self, name: Union[bytes, bytearray, memoryview]) -> None: ...
    @overload
    def enableAttributeArray(self, location: int) -> None: ...
    @overload
    def enableAttributeArray(self, name: Union[bytes, bytearray, memoryview]) -> None: ...
    @staticmethod
    def hasOpenGLShaderPrograms(context: Optional[PySide6.QtGui.QOpenGLContext] = ...) -> bool: ...
    def isLinked(self) -> bool: ...
    def link(self) -> bool: ...
    def log(self) -> str: ...
    def maxGeometryOutputVertices(self) -> int: ...
    def patchVertexCount(self) -> int: ...
    def programId(self) -> int: ...
    def release(self) -> None: ...
    def removeAllShaders(self) -> None: ...
    def removeShader(self, shader: PySide6.QtOpenGL.QOpenGLShader) -> None: ...
    @overload
    def setAttributeArray(self, location: int, type: int, values: int, tupleSize: int, stride: int = ...) -> None: ...
    @overload
    def setAttributeArray(self, name: Union[bytes, bytearray, memoryview], type: int, values: int, tupleSize: int, stride: int = ...) -> None: ...
    @overload
    def setAttributeBuffer(self, location: int, type: int, offset: int, tupleSize: int, stride: int = ...) -> None: ...
    @overload
    def setAttributeBuffer(self, name: Union[bytes, bytearray, memoryview], type: int, offset: int, tupleSize: int, stride: int = ...) -> None: ...
    @overload
    def setAttributeValue(self, location: int, value: PySide6.QtGui.QVector2D) -> None: ...
    @overload
    def setAttributeValue(self, location: int, value: PySide6.QtGui.QVector3D) -> None: ...
    @overload
    def setAttributeValue(self, location: int, value: PySide6.QtGui.QVector4D) -> None: ...
    @overload
    def setAttributeValue(self, location: int, value: Union[PySide6.QtGui.QColor, PySide6.QtGui.QRgba64, Any, PySide6.QtCore.Qt.GlobalColor, str, int]) -> None: ...
    @overload
    def setAttributeValue(self, name: Union[bytes, bytearray, memoryview], value: PySide6.QtGui.QVector2D) -> None: ...
    @overload
    def setAttributeValue(self, name: Union[bytes, bytearray, memoryview], value: PySide6.QtGui.QVector3D) -> None: ...
    @overload
    def setAttributeValue(self, name: Union[bytes, bytearray, memoryview], value: PySide6.QtGui.QVector4D) -> None: ...
    @overload
    def setAttributeValue(self, name: Union[bytes, bytearray, memoryview], value: Union[PySide6.QtGui.QColor, PySide6.QtGui.QRgba64, Any, PySide6.QtCore.Qt.GlobalColor, str, int]) -> None: ...
    def setDefaultInnerTessellationLevels(self, levels: Sequence[float]) -> None: ...
    def setDefaultOuterTessellationLevels(self, levels: Sequence[float]) -> None: ...
    def setPatchVertexCount(self, count: int) -> None: ...
    @overload
    def setUniformValue(self, location: int, color: Union[PySide6.QtGui.QColor, PySide6.QtGui.QRgba64, Any, PySide6.QtCore.Qt.GlobalColor, str, int]) -> None: ...
    @overload
    def setUniformValue(self, location: int, point: PySide6.QtCore.QPoint) -> None: ...
    @overload
    def setUniformValue(self, location: int, point: Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element]) -> None: ...
    @overload
    def setUniformValue(self, location: int, size: PySide6.QtCore.QSize) -> None: ...
    @overload
    def setUniformValue(self, location: int, size: Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize]) -> None: ...
    @overload
    def setUniformValue(self, location: int, value: PySide6.QtGui.QMatrix2x2) -> None: ...
    @overload
    def setUniformValue(self, location: int, value: PySide6.QtGui.QMatrix2x3) -> None: ...
    @overload
    def setUniformValue(self, location: int, value: PySide6.QtGui.QMatrix2x4) -> None: ...
    @overload
    def setUniformValue(self, location: int, value: PySide6.QtGui.QMatrix3x2) -> None: ...
    @overload
    def setUniformValue(self, location: int, value: PySide6.QtGui.QMatrix3x3) -> None: ...
    @overload
    def setUniformValue(self, location: int, value: PySide6.QtGui.QMatrix3x4) -> None: ...
    @overload
    def setUniformValue(self, location: int, value: PySide6.QtGui.QMatrix4x2) -> None: ...
    @overload
    def setUniformValue(self, location: int, value: PySide6.QtGui.QMatrix4x3) -> None: ...
    @overload
    def setUniformValue(self, location: int, value: PySide6.QtGui.QTransform) -> None: ...
    @overload
    def setUniformValue(self, location: int, value: PySide6.QtGui.QVector2D) -> None: ...
    @overload
    def setUniformValue(self, location: int, value: PySide6.QtGui.QVector3D) -> None: ...
    @overload
    def setUniformValue(self, location: int, value: PySide6.QtGui.QVector4D) -> None: ...
    @overload
    def setUniformValue(self, location: int, value: int) -> None: ...
    @overload
    def setUniformValue(self, location: int, value: Union[PySide6.QtGui.QMatrix4x4, PySide6.QtGui.QTransform]) -> None: ...
    @overload
    def setUniformValue(self, location: int, value: int) -> None: ...
    @overload
    def setUniformValue(self, name: Union[bytes, bytearray, memoryview], color: Union[PySide6.QtGui.QColor, PySide6.QtGui.QRgba64, Any, PySide6.QtCore.Qt.GlobalColor, str, int]) -> None: ...
    @overload
    def setUniformValue(self, name: Union[bytes, bytearray, memoryview], point: PySide6.QtCore.QPoint) -> None: ...
    @overload
    def setUniformValue(self, name: Union[bytes, bytearray, memoryview], point: Union[PySide6.QtCore.QPointF, PySide6.QtCore.QPoint, PySide6.QtGui.QPainterPath.Element]) -> None: ...
    @overload
    def setUniformValue(self, name: Union[bytes, bytearray, memoryview], size: PySide6.QtCore.QSize) -> None: ...
    @overload
    def setUniformValue(self, name: Union[bytes, bytearray, memoryview], size: Union[PySide6.QtCore.QSizeF, PySide6.QtCore.QSize]) -> None: ...
    @overload
    def setUniformValue(self, name: Union[bytes, bytearray, memoryview], value: PySide6.QtGui.QMatrix2x2) -> None: ...
    @overload
    def setUniformValue(self, name: Union[bytes, bytearray, memoryview], value: PySide6.QtGui.QMatrix2x3) -> None: ...
    @overload
    def setUniformValue(self, name: Union[bytes, bytearray, memoryview], value: PySide6.QtGui.QMatrix2x4) -> None: ...
    @overload
    def setUniformValue(self, name: Union[bytes, bytearray, memoryview], value: PySide6.QtGui.QMatrix3x2) -> None: ...
    @overload
    def setUniformValue(self, name: Union[bytes, bytearray, memoryview], value: PySide6.QtGui.QMatrix3x3) -> None: ...
    @overload
    def setUniformValue(self, name: Union[bytes, bytearray, memoryview], value: PySide6.QtGui.QMatrix3x4) -> None: ...
    @overload
    def setUniformValue(self, name: Union[bytes, bytearray, memoryview], value: PySide6.QtGui.QMatrix4x2) -> None: ...
    @overload
    def setUniformValue(self, name: Union[bytes, bytearray, memoryview], value: PySide6.QtGui.QMatrix4x3) -> None: ...
    @overload
    def setUniformValue(self, name: Union[bytes, bytearray, memoryview], value: PySide6.QtGui.QTransform) -> None: ...
    @overload
    def setUniformValue(self, name: Union[bytes, bytearray, memoryview], value: PySide6.QtGui.QVector2D) -> None: ...
    @overload
    def setUniformValue(self, name: Union[bytes, bytearray, memoryview], value: PySide6.QtGui.QVector3D) -> None: ...
    @overload
    def setUniformValue(self, name: Union[bytes, bytearray, memoryview], value: PySide6.QtGui.QVector4D) -> None: ...
    @overload
    def setUniformValue(self, name: Union[bytes, bytearray, memoryview], value: Union[PySide6.QtGui.QMatrix4x4, PySide6.QtGui.QTransform]) -> None: ...
    @overload
    def setUniformValue1f(self, arg__1: Union[bytes, bytearray, memoryview], arg__2: float) -> None: ...
    @overload
    def setUniformValue1f(self, arg__1: int, arg__2: float) -> None: ...
    @overload
    def setUniformValue1i(self, arg__1: Union[bytes, bytearray, memoryview], arg__2: int) -> None: ...
    @overload
    def setUniformValue1i(self, arg__1: int, arg__2: int) -> None: ...
    @overload
    def setUniformValueArray(self, location: int, values: Sequence[int], count: int) -> None: ...
    @overload
    def setUniformValueArray(self, location: int, values: Sequence[int], count: int) -> None: ...
    @overload
    def setUniformValueArray(self, name: Union[bytes, bytearray, memoryview], values: Sequence[int], count: int) -> None: ...
    @overload
    def setUniformValueArray(self, name: Union[bytes, bytearray, memoryview], values: Sequence[int], count: int) -> None: ...
    def shaders(self) -> List[PySide6.QtOpenGL.QOpenGLShader]: ...
    @overload
    def uniformLocation(self, name: str) -> int: ...
    @overload
    def uniformLocation(self, name: Union[bytes, bytearray, memoryview]) -> int: ...
    @overload
    def uniformLocation(self, name: Union[PySide6.QtCore.QByteArray, bytes, bytearray, memoryview]) -> int: ...


class QOpenGLTexture(Shiboken.Object):

    class BindingTarget(enum.Enum):

        BindingTarget1D          : QOpenGLTexture.BindingTarget = ... # 0x8068
        BindingTarget2D          : QOpenGLTexture.BindingTarget = ... # 0x8069
        BindingTarget3D          : QOpenGLTexture.BindingTarget = ... # 0x806a
        BindingTargetRectangle   : QOpenGLTexture.BindingTarget = ... # 0x84f6
        BindingTargetCubeMap     : QOpenGLTexture.BindingTarget = ... # 0x8514
        BindingTarget1DArray     : QOpenGLTexture.BindingTarget = ... # 0x8c1c
        BindingTarget2DArray     : QOpenGLTexture.BindingTarget = ... # 0x8c1d
        BindingTargetBuffer      : QOpenGLTexture.BindingTarget = ... # 0x8c2c
        BindingTargetCubeMapArray: QOpenGLTexture.BindingTarget = ... # 0x900a
        BindingTarget2DMultisample: QOpenGLTexture.BindingTarget = ... # 0x9104
        BindingTarget2DMultisampleArray: QOpenGLTexture.BindingTarget = ... # 0x9105

    class ComparisonFunction(enum.Enum):

        CompareNever             : QOpenGLTexture.ComparisonFunction = ... # 0x200
        CompareLess              : QOpenGLTexture.ComparisonFunction = ... # 0x201
        CompareEqual             : QOpenGLTexture.ComparisonFunction = ... # 0x202
        CompareLessEqual         : QOpenGLTexture.ComparisonFunction = ... # 0x203
        CompareGreater           : QOpenGLTexture.ComparisonFunction = ... # 0x204
        CommpareNotEqual         : QOpenGLTexture.ComparisonFunction = ... # 0x205
        CompareNotEqual          : QOpenGLTexture.ComparisonFunction = ... # 0x205
        CompareGreaterEqual      : QOpenGLTexture.ComparisonFunction = ... # 0x206
        CompareAlways            : QOpenGLTexture.ComparisonFunction = ... # 0x207

    class ComparisonMode(enum.Enum):

        CompareNone              : QOpenGLTexture.ComparisonMode = ... # 0x0
        CompareRefToTexture      : QOpenGLTexture.ComparisonMode = ... # 0x884e

    class CoordinateDirection(enum.Enum):

        DirectionS               : QOpenGLTexture.CoordinateDirection = ... # 0x2802
        DirectionT               : QOpenGLTexture.CoordinateDirection = ... # 0x2803
        DirectionR               : QOpenGLTexture.CoordinateDirection = ... # 0x8072

    class CubeMapFace(enum.Enum):

        CubeMapPositiveX         : QOpenGLTexture.CubeMapFace = ... # 0x8515
        CubeMapNegativeX         : QOpenGLTexture.CubeMapFace = ... # 0x8516
        CubeMapPositiveY         : QOpenGLTexture.CubeMapFace = ... # 0x8517
        CubeMapNegativeY         : QOpenGLTexture.CubeMapFace = ... # 0x8518
        CubeMapPositiveZ         : QOpenGLTexture.CubeMapFace = ... # 0x8519
        CubeMapNegativeZ         : QOpenGLTexture.CubeMapFace = ... # 0x851a

    class DepthStencilMode(enum.Enum):

        StencilMode              : QOpenGLTexture.DepthStencilMode = ... # 0x1901
        DepthMode                : QOpenGLTexture.DepthStencilMode = ... # 0x1902

    class Feature(enum.Flag):

        ImmutableStorage         : QOpenGLTexture.Feature = ... # 0x1
        ImmutableMultisampleStorage: QOpenGLTexture.Feature = ... # 0x2
        TextureRectangle         : QOpenGLTexture.Feature = ... # 0x4
        TextureArrays            : QOpenGLTexture.Feature = ... # 0x8
        Texture3D                : QOpenGLTexture.Feature = ... # 0x10
        TextureMultisample       : QOpenGLTexture.Feature = ... # 0x20
        TextureBuffer            : QOpenGLTexture.Feature = ... # 0x40
        TextureCubeMapArrays     : QOpenGLTexture.Feature = ... # 0x80
        Swizzle                  : QOpenGLTexture.Feature = ... # 0x100
        StencilTexturing         : QOpenGLTexture.Feature = ... # 0x200
        AnisotropicFiltering     : QOpenGLTexture.Feature = ... # 0x400
        NPOTTextures             : QOpenGLTexture.Feature = ... # 0x800
        NPOTTextureRepeat        : QOpenGLTexture.Feature = ... # 0x1000
        Texture1D                : QOpenGLTexture.Feature = ... # 0x2000
        TextureComparisonOperators: QOpenGLTexture.Feature = ... # 0x4000
        TextureMipMapLevel       : QOpenGLTexture.Feature = ... # 0x8000
        MaxFeatureFlag           : QOpenGLTexture.Feature = ... # 0x10000

    class Filter(enum.Enum):

        Nearest                  : QOpenGLTexture.Filter = ... # 0x2600
        Linear                   : QOpenGLTexture.Filter = ... # 0x2601
        NearestMipMapNearest     : QOpenGLTexture.Filter = ... # 0x2700
        LinearMipMapNearest      : QOpenGLTexture.Filter = ... # 0x2701
        NearestMipMapLinear      : QOpenGLTexture.Filter = ... # 0x2702
        LinearMipMapLinear       : QOpenGLTexture.Filter = ... # 0x2703

    class MipMapGeneration(enum.Enum):

        GenerateMipMaps          : QOpenGLTexture.MipMapGeneration = ... # 0x0
        DontGenerateMipMaps      : QOpenGLTexture.MipMapGeneration = ... # 0x1

    class PixelFormat(enum.Enum):

        NoSourceFormat           : QOpenGLTexture.PixelFormat = ... # 0x0
        Stencil                  : QOpenGLTexture.PixelFormat = ... # 0x1901
        Depth                    : QOpenGLTexture.PixelFormat = ... # 0x1902
        Red                      : QOpenGLTexture.PixelFormat = ... # 0x1903
        Alpha                    : QOpenGLTexture.PixelFormat = ... # 0x1906
        RGB                      : QOpenGLTexture.PixelFormat = ... # 0x1907
        RGBA                     : QOpenGLTexture.PixelFormat = ... # 0x1908
        Luminance                : QOpenGLTexture.PixelFormat = ... # 0x1909
        LuminanceAlpha           : QOpenGLTexture.PixelFormat = ... # 0x190a
        BGR                      : QOpenGLTexture.PixelFormat = ... # 0x80e0
        BGRA                     : QOpenGLTexture.PixelFormat = ... # 0x80e1
        RG                       : QOpenGLTexture.PixelFormat = ... # 0x8227
        RG_Integer               : QOpenGLTexture.PixelFormat = ... # 0x8228
        DepthStencil             : QOpenGLTexture.PixelFormat = ... # 0x84f9
        Red_Integer              : QOpenGLTexture.PixelFormat = ... # 0x8d94
        RGB_Integer              : QOpenGLTexture.PixelFormat = ... # 0x8d98
        RGBA_Integer             : QOpenGLTexture.PixelFormat = ... # 0x8d99
        BGR_Integer              : QOpenGLTexture.PixelFormat = ... # 0x8d9a
        BGRA_Integer             : QOpenGLTexture.PixelFormat = ... # 0x8d9b

    class PixelType(enum.Enum):

        NoPixelType              : QOpenGLTexture.PixelType = ... # 0x0
        Int8                     : QOpenGLTexture.PixelType = ... # 0x1400
        UInt8                    : QOpenGLTexture.PixelType = ... # 0x1401
        Int16                    : QOpenGLTexture.PixelType = ... # 0x1402
        UInt16                   : QOpenGLTexture.PixelType = ... # 0x1403
        Int32                    : QOpenGLTexture.PixelType = ... # 0x1404
        UInt32                   : QOpenGLTexture.PixelType = ... # 0x1405
        Float32                  : QOpenGLTexture.PixelType = ... # 0x1406
        Float16                  : QOpenGLTexture.PixelType = ... # 0x140b
        UInt8_RG3B2              : QOpenGLTexture.PixelType = ... # 0x8032
        UInt16_RGBA4             : QOpenGLTexture.PixelType = ... # 0x8033
        UInt16_RGB5A1            : QOpenGLTexture.PixelType = ... # 0x8034
        UInt32_RGBA8             : QOpenGLTexture.PixelType = ... # 0x8035
        UInt32_RGB10A2           : QOpenGLTexture.PixelType = ... # 0x8036
        UInt8_RG3B2_Rev          : QOpenGLTexture.PixelType = ... # 0x8362
        UInt16_R5G6B5            : QOpenGLTexture.PixelType = ... # 0x8363
        UInt16_R5G6B5_Rev        : QOpenGLTexture.PixelType = ... # 0x8364
        UInt16_RGBA4_Rev         : QOpenGLTexture.PixelType = ... # 0x8365
        UInt16_RGB5A1_Rev        : QOpenGLTexture.PixelType = ... # 0x8366
        UInt32_RGBA8_Rev         : QOpenGLTexture.PixelType = ... # 0x8367
        UInt32_RGB10A2_Rev       : QOpenGLTexture.PixelType = ... # 0x8368
        UInt32_D24S8             : QOpenGLTexture.PixelType = ... # 0x84fa
        UInt32_RG11B10F          : QOpenGLTexture.PixelType = ... # 0x8c3b
        UInt32_RGB9_E5           : QOpenGLTexture.PixelType = ... # 0x8c3e
        Float16OES               : QOpenGLTexture.PixelType = ... # 0x8d61
        Float32_D32_UInt32_S8_X24: QOpenGLTexture.PixelType = ... # 0x8dad

    class SwizzleComponent(enum.Enum):

        SwizzleRed               : QOpenGLTexture.SwizzleComponent = ... # 0x8e42
        SwizzleGreen             : QOpenGLTexture.SwizzleComponent = ... # 0x8e43
        SwizzleBlue              : QOpenGLTexture.SwizzleComponent = ... # 0x8e44
        SwizzleAlpha             : QOpenGLTexture.SwizzleComponent = ... # 0x8e45

    class SwizzleValue(enum.Enum):

        ZeroValue                : QOpenGLTexture.SwizzleValue = ... # 0x0
        OneValue                 : QOpenGLTexture.SwizzleValue = ... # 0x1
        RedValue                 : QOpenGLTexture.SwizzleValue = ... # 0x1903
        GreenValue               : QOpenGLTexture.SwizzleValue = ... # 0x1904
        BlueValue                : QOpenGLTexture.SwizzleValue = ... # 0x1905
        AlphaValue               : QOpenGLTexture.SwizzleValue = ... # 0x1906

    class Target(enum.Enum):

        Target1D                 : QOpenGLTexture.Target = ... # 0xde0
        Target2D                 : QOpenGLTexture.Target = ... # 0xde1
        Target3D                 : QOpenGLTexture.Target = ... # 0x806f
        TargetRectangle          : QOpenGLTexture.Target = ... # 0x84f5
        TargetCubeMap            : QOpenGLTexture.Target = ... # 0x8513
        Target1DArray            : QOpenGLTexture.Target = ... # 0x8c18
        Target2DArray            : QOpenGLTexture.Target = ... # 0x8c1a
        TargetBuffer             : QOpenGLTexture.Target = ... # 0x8c2a
        TargetCubeMapArray       : QOpenGLTexture.Target = ... # 0x9009
        Target2DMultisample      : QOpenGLTexture.Target = ... # 0x9100
        Target2DMultisampleArray : QOpenGLTexture.Target = ... # 0x9102

    class TextureFormat(enum.Enum):

        NoFormat                 : QOpenGLTexture.TextureFormat = ... # 0x0
        DepthFormat              : QOpenGLTexture.TextureFormat = ... # 0x1902
        AlphaFormat              : QOpenGLTexture.TextureFormat = ... # 0x1906
        RGBFormat                : QOpenGLTexture.TextureFormat = ... # 0x1907
        RGBAFormat               : QOpenGLTexture.TextureFormat = ... # 0x1908
        LuminanceFormat          : QOpenGLTexture.TextureFormat = ... # 0x1909
        LuminanceAlphaFormat     : QOpenGLTexture.TextureFormat = ... # 0x190a
        RG3B2                    : QOpenGLTexture.TextureFormat = ... # 0x2a10
        RGB8_UNorm               : QOpenGLTexture.TextureFormat = ... # 0x8051
        RGB16_UNorm              : QOpenGLTexture.TextureFormat = ... # 0x8054
        RGBA4                    : QOpenGLTexture.TextureFormat = ... # 0x8056
        RGB5A1                   : QOpenGLTexture.TextureFormat = ... # 0x8057
        RGBA8_UNorm              : QOpenGLTexture.TextureFormat = ... # 0x8058
        RGBA16_UNorm             : QOpenGLTexture.TextureFormat = ... # 0x805b
        D16                      : QOpenGLTexture.TextureFormat = ... # 0x81a5
        D24                      : QOpenGLTexture.TextureFormat = ... # 0x81a6
        D32                      : QOpenGLTexture.TextureFormat = ... # 0x81a7
        R8_UNorm                 : QOpenGLTexture.TextureFormat = ... # 0x8229
        R16_UNorm                : QOpenGLTexture.TextureFormat = ... # 0x822a
        RG8_UNorm                : QOpenGLTexture.TextureFormat = ... # 0x822b
        RG16_UNorm               : QOpenGLTexture.TextureFormat = ... # 0x822c
        R16F                     : QOpenGLTexture.TextureFormat = ... # 0x822d
        R32F                     : QOpenGLTexture.TextureFormat = ... # 0x822e
        RG16F                    : QOpenGLTexture.TextureFormat = ... # 0x822f
        RG32F                    : QOpenGLTexture.TextureFormat = ... # 0x8230
        R8I                      : QOpenGLTexture.TextureFormat = ... # 0x8231
        R8U                      : QOpenGLTexture.TextureFormat = ... # 0x8232
        R16I                     : QOpenGLTexture.TextureFormat = ... # 0x8233
        R16U                     : QOpenGLTexture.TextureFormat = ... # 0x8234
        R32I                     : QOpenGLTexture.TextureFormat = ... # 0x8235
        R32U                     : QOpenGLTexture.TextureFormat = ... # 0x8236
        RG8I                     : QOpenGLTexture.TextureFormat = ... # 0x8237
        RG8U                     : QOpenGLTexture.TextureFormat = ... # 0x8238
        RG16I                    : QOpenGLTexture.TextureFormat = ... # 0x8239
        RG16U                    : QOpenGLTexture.TextureFormat = ... # 0x823a
        RG32I                    : QOpenGLTexture.TextureFormat = ... # 0x823b
        RG32U                    : QOpenGLTexture.TextureFormat = ... # 0x823c
        RGB_DXT1                 : QOpenGLTexture.TextureFormat = ... # 0x83f0
        RGBA_DXT1                : QOpenGLTexture.TextureFormat = ... # 0x83f1
        RGBA_DXT3                : QOpenGLTexture.TextureFormat = ... # 0x83f2
        RGBA_DXT5                : QOpenGLTexture.TextureFormat = ... # 0x83f3
        RGBA32F                  : QOpenGLTexture.TextureFormat = ... # 0x8814
        RGB32F                   : QOpenGLTexture.TextureFormat = ... # 0x8815
        RGBA16F                  : QOpenGLTexture.TextureFormat = ... # 0x881a
        RGB16F                   : QOpenGLTexture.TextureFormat = ... # 0x881b
        D24S8                    : QOpenGLTexture.TextureFormat = ... # 0x88f0
        RG11B10F                 : QOpenGLTexture.TextureFormat = ... # 0x8c3a
        RGB9E5                   : QOpenGLTexture.TextureFormat = ... # 0x8c3d
        SRGB8                    : QOpenGLTexture.TextureFormat = ... # 0x8c41
        SRGB8_Alpha8             : QOpenGLTexture.TextureFormat = ... # 0x8c43
        SRGB_DXT1                : QOpenGLTexture.TextureFormat = ... # 0x8c4c
        SRGB_Alpha_DXT1          : QOpenGLTexture.TextureFormat = ... # 0x8c4d
        SRGB_Alpha_DXT3          : QOpenGLTexture.TextureFormat = ... # 0x8c4e
        SRGB_Alpha_DXT5          : QOpenGLTexture.TextureFormat = ... # 0x8c4f
        D32F                     : QOpenGLTexture.TextureFormat = ... # 0x8cac
        D32FS8X24                : QOpenGLTexture.TextureFormat = ... # 0x8cad
        S8                       : QOpenGLTexture.TextureFormat = ... # 0x8d48
        R5G6B5                   : QOpenGLTexture.TextureFormat = ... # 0x8d62
        RGB8_ETC1                : QOpenGLTexture.TextureFormat = ... # 0x8d64
        RGBA32U                  : QOpenGLTexture.TextureFormat = ... # 0x8d70
        RGB32U                   : QOpenGLTexture.TextureFormat = ... # 0x8d71
        RGBA16U                  : QOpenGLTexture.TextureFormat = ... # 0x8d76
        RGB16U                   : QOpenGLTexture.TextureFormat = ... # 0x8d77
        RGBA8U                   : QOpenGLTexture.TextureFormat = ... # 0x8d7c
        RGB8U                    : QOpenGLTexture.TextureFormat = ... # 0x8d7d
        RGBA32I                  : QOpenGLTexture.TextureFormat = ... # 0x8d82
        RGB32I                   : QOpenGLTexture.TextureFormat = ... # 0x8d83
        RGBA16I                  : QOpenGLTexture.TextureFormat = ... # 0x8d88
        RGB16I                   : QOpenGLTexture.TextureFormat = ... # 0x8d89
        RGBA8I                   : QOpenGLTexture.TextureFormat = ... # 0x8d8e
        RGB8I                    : QOpenGLTexture.TextureFormat = ... # 0x8d8f
        R_ATI1N_UNorm            : QOpenGLTexture.TextureFormat = ... # 0x8dbb
        R_ATI1N_SNorm            : QOpenGLTexture.TextureFormat = ... # 0x8dbc
        RG_ATI2N_UNorm           : QOpenGLTexture.TextureFormat = ... # 0x8dbd
        RG_ATI2N_SNorm           : QOpenGLTexture.TextureFormat = ... # 0x8dbe
        RGB_BP_UNorm             : QOpenGLTexture.TextureFormat = ... # 0x8e8c
        SRGB_BP_UNorm            : QOpenGLTexture.TextureFormat = ... # 0x8e8d
        RGB_BP_SIGNED_FLOAT      : QOpenGLTexture.TextureFormat = ... # 0x8e8e
        RGB_BP_UNSIGNED_FLOAT    : QOpenGLTexture.TextureFormat = ... # 0x8e8f
        R8_SNorm                 : QOpenGLTexture.TextureFormat = ... # 0x8f94
        RG8_SNorm                : QOpenGLTexture.TextureFormat = ... # 0x8f95
        RGB8_SNorm               : QOpenGLTexture.TextureFormat = ... # 0x8f96
        RGBA8_SNorm              : QOpenGLTexture.TextureFormat = ... # 0x8f97
        R16_SNorm                : QOpenGLTexture.TextureFormat = ... # 0x8f98
        RG16_SNorm               : QOpenGLTexture.TextureFormat = ... # 0x8f99
        RGB16_SNorm              : QOpenGLTexture.TextureFormat = ... # 0x8f9a
        RGBA16_SNorm             : QOpenGLTexture.TextureFormat = ... # 0x8f9b
        RGB10A2                  : QOpenGLTexture.TextureFormat = ... # 0x906f
        R11_EAC_UNorm            : QOpenGLTexture.TextureFormat = ... # 0x9270
        R11_EAC_SNorm            : QOpenGLTexture.TextureFormat = ... # 0x9271
        RG11_EAC_UNorm           : QOpenGLTexture.TextureFormat = ... # 0x9272
        RG11_EAC_SNorm           : QOpenGLTexture.TextureFormat = ... # 0x9273
        RGB8_ETC2                : QOpenGLTexture.TextureFormat = ... # 0x9274
        SRGB8_ETC2               : QOpenGLTexture.TextureFormat = ... # 0x9275
        RGB8_PunchThrough_Alpha1_ETC2: QOpenGLTexture.TextureFormat = ... # 0x9276
        SRGB8_PunchThrough_Alpha1_ETC2: QOpenGLTexture.TextureFormat = ... # 0x9277
        RGBA8_ETC2_EAC           : QOpenGLTexture.TextureFormat = ... # 0x9278
        SRGB8_Alpha8_ETC2_EAC    : QOpenGLTexture.TextureFormat = ... # 0x9279
        RGBA_ASTC_4x4            : QOpenGLTexture.TextureFormat = ... # 0x93b0
        RGBA_ASTC_5x4            : QOpenGLTexture.TextureFormat = ... # 0x93b1
        RGBA_ASTC_5x5            : QOpenGLTexture.TextureFormat = ... # 0x93b2
        RGBA_ASTC_6x5            : QOpenGLTexture.TextureFormat = ... # 0x93b3
        RGBA_ASTC_6x6            : QOpenGLTexture.TextureFormat = ... # 0x93b4
        RGBA_ASTC_8x5            : QOpenGLTexture.TextureFormat = ... # 0x93b5
        RGBA_ASTC_8x6            : QOpenGLTexture.TextureFormat = ... # 0x93b6
        RGBA_ASTC_8x8            : QOpenGLTexture.TextureFormat = ... # 0x93b7
        RGBA_ASTC_10x5           : QOpenGLTexture.TextureFormat = ... # 0x93b8
        RGBA_ASTC_10x6           : QOpenGLTexture.TextureFormat = ... # 0x93b9
        RGBA_ASTC_10x8           : QOpenGLTexture.TextureFormat = ... # 0x93ba
        RGBA_ASTC_10x10          : QOpenGLTexture.TextureFormat = ... # 0x93bb
        RGBA_ASTC_12x10          : QOpenGLTexture.TextureFormat = ... # 0x93bc
        RGBA_ASTC_12x12          : QOpenGLTexture.TextureFormat = ... # 0x93bd
        SRGB8_Alpha8_ASTC_4x4    : QOpenGLTexture.TextureFormat = ... # 0x93d0
        SRGB8_Alpha8_ASTC_5x4    : QOpenGLTexture.TextureFormat = ... # 0x93d1
        SRGB8_Alpha8_ASTC_5x5    : QOpenGLTexture.TextureFormat = ... # 0x93d2
        SRGB8_Alpha8_ASTC_6x5    : QOpenGLTexture.TextureFormat = ... # 0x93d3
        SRGB8_Alpha8_ASTC_6x6    : QOpenGLTexture.TextureFormat = ... # 0x93d4
        SRGB8_Alpha8_ASTC_8x5    : QOpenGLTexture.TextureFormat = ... # 0x93d5
        SRGB8_Alpha8_ASTC_8x6    : QOpenGLTexture.TextureFormat = ... # 0x93d6
        SRGB8_Alpha8_ASTC_8x8    : QOpenGLTexture.TextureFormat = ... # 0x93d7
        SRGB8_Alpha8_ASTC_10x5   : QOpenGLTexture.TextureFormat = ... # 0x93d8
        SRGB8_Alpha8_ASTC_10x6   : QOpenGLTexture.TextureFormat = ... # 0x93d9
        SRGB8_Alpha8_ASTC_10x8   : QOpenGLTexture.TextureFormat = ... # 0x93da
        SRGB8_Alpha8_ASTC_10x10  : QOpenGLTexture.TextureFormat = ... # 0x93db
        SRGB8_Alpha8_ASTC_12x10  : QOpenGLTexture.TextureFormat = ... # 0x93dc
        SRGB8_Alpha8_ASTC_12x12  : QOpenGLTexture.TextureFormat = ... # 0x93dd

    class TextureFormatClass(enum.Enum):

        NoFormatClass            : QOpenGLTexture.TextureFormatClass = ... # 0x0
        FormatClass_128Bit       : QOpenGLTexture.TextureFormatClass = ... # 0x1
        FormatClass_96Bit        : QOpenGLTexture.TextureFormatClass = ... # 0x2
        FormatClass_64Bit        : QOpenGLTexture.TextureFormatClass = ... # 0x3
        FormatClass_48Bit        : QOpenGLTexture.TextureFormatClass = ... # 0x4
        FormatClass_32Bit        : QOpenGLTexture.TextureFormatClass = ... # 0x5
        FormatClass_24Bit        : QOpenGLTexture.TextureFormatClass = ... # 0x6
        FormatClass_16Bit        : QOpenGLTexture.TextureFormatClass = ... # 0x7
        FormatClass_8Bit         : QOpenGLTexture.TextureFormatClass = ... # 0x8
        FormatClass_RGTC1_R      : QOpenGLTexture.TextureFormatClass = ... # 0x9
        FormatClass_RGTC2_RG     : QOpenGLTexture.TextureFormatClass = ... # 0xa
        FormatClass_BPTC_Unorm   : QOpenGLTexture.TextureFormatClass = ... # 0xb
        FormatClass_BPTC_Float   : QOpenGLTexture.TextureFormatClass = ... # 0xc
        FormatClass_S3TC_DXT1_RGB: QOpenGLTexture.TextureFormatClass = ... # 0xd
        FormatClass_S3TC_DXT1_RGBA: QOpenGLTexture.TextureFormatClass = ... # 0xe
        FormatClass_S3TC_DXT3_RGBA: QOpenGLTexture.TextureFormatClass = ... # 0xf
        FormatClass_S3TC_DXT5_RGBA: QOpenGLTexture.TextureFormatClass = ... # 0x10
        FormatClass_Unique       : QOpenGLTexture.TextureFormatClass = ... # 0x11

    class TextureUnitReset(enum.Enum):

        ResetTextureUnit         : QOpenGLTexture.TextureUnitReset = ... # 0x0
        DontResetTextureUnit     : QOpenGLTexture.TextureUnitReset = ... # 0x1

    class WrapMode(enum.Enum):

        Repeat                   : QOpenGLTexture.WrapMode = ... # 0x2901
        ClampToBorder            : QOpenGLTexture.WrapMode = ... # 0x812d
        ClampToEdge              : QOpenGLTexture.WrapMode = ... # 0x812f
        MirroredRepeat           : QOpenGLTexture.WrapMode = ... # 0x8370


    @overload
    def __init__(self, image: Union[PySide6.QtGui.QImage, str], genMipMaps: PySide6.QtOpenGL.QOpenGLTexture.MipMapGeneration = ...) -> None: ...
    @overload
    def __init__(self, target: PySide6.QtOpenGL.QOpenGLTexture.Target) -> None: ...

    @overload
    def allocateStorage(self) -> None: ...
    @overload
    def allocateStorage(self, pixelFormat: PySide6.QtOpenGL.QOpenGLTexture.PixelFormat, pixelType: PySide6.QtOpenGL.QOpenGLTexture.PixelType) -> None: ...
    @overload
    def bind(self) -> None: ...
    @overload
    def bind(self, unit: int, reset: PySide6.QtOpenGL.QOpenGLTexture.TextureUnitReset = ...) -> None: ...
    def borderColor(self) -> PySide6.QtGui.QColor: ...
    @overload
    @staticmethod
    def boundTextureId(target: PySide6.QtOpenGL.QOpenGLTexture.BindingTarget) -> int: ...
    @overload
    @staticmethod
    def boundTextureId(unit: int, target: PySide6.QtOpenGL.QOpenGLTexture.BindingTarget) -> int: ...
    def comparisonFunction(self) -> PySide6.QtOpenGL.QOpenGLTexture.ComparisonFunction: ...
    def comparisonMode(self) -> PySide6.QtOpenGL.QOpenGLTexture.ComparisonMode: ...
    def create(self) -> bool: ...
    def createTextureView(self, target: PySide6.QtOpenGL.QOpenGLTexture.Target, viewFormat: PySide6.QtOpenGL.QOpenGLTexture.TextureFormat, minimumMipmapLevel: int, maximumMipmapLevel: int, minimumLayer: int, maximumLayer: int) -> PySide6.QtOpenGL.QOpenGLTexture: ...
    def depth(self) -> int: ...
    def depthStencilMode(self) -> PySide6.QtOpenGL.QOpenGLTexture.DepthStencilMode: ...
    def destroy(self) -> None: ...
    def faces(self) -> int: ...
    def format(self) -> PySide6.QtOpenGL.QOpenGLTexture.TextureFormat: ...
    @overload
    def generateMipMaps(self) -> None: ...
    @overload
    def generateMipMaps(self, baseLevel: int, resetBaseLevel: bool = ...) -> None: ...
    @staticmethod
    def hasFeature(feature: PySide6.QtOpenGL.QOpenGLTexture.Feature) -> bool: ...
    def height(self) -> int: ...
    def isAutoMipMapGenerationEnabled(self) -> bool: ...
    @overload
    def isBound(self) -> bool: ...
    @overload
    def isBound(self, unit: int) -> bool: ...
    def isCreated(self) -> bool: ...
    def isFixedSamplePositions(self) -> bool: ...
    def isStorageAllocated(self) -> bool: ...
    def isTextureView(self) -> bool: ...
    def layers(self) -> int: ...
    def levelOfDetailRange(self) -> Tuple[float, float]: ...
    def levelofDetailBias(self) -> float: ...
    def magnificationFilter(self) -> PySide6.QtOpenGL.QOpenGLTexture.Filter: ...
    def maximumAnisotropy(self) -> float: ...
    def maximumLevelOfDetail(self) -> float: ...
    def maximumMipLevels(self) -> int: ...
    def minMagFilters(self) -> Tuple[PySide6.QtOpenGL.QOpenGLTexture.Filter, PySide6.QtOpenGL.QOpenGLTexture.Filter]: ...
    def minificationFilter(self) -> PySide6.QtOpenGL.QOpenGLTexture.Filter: ...
    def minimumLevelOfDetail(self) -> float: ...
    def mipBaseLevel(self) -> int: ...
    def mipLevelRange(self) -> Tuple[int, int]: ...
    def mipLevels(self) -> int: ...
    def mipMaxLevel(self) -> int: ...
    @overload
    def release(self) -> None: ...
    @overload
    def release(self, unit: int, reset: PySide6.QtOpenGL.QOpenGLTexture.TextureUnitReset = ...) -> None: ...
    def samples(self) -> int: ...
    def setAutoMipMapGenerationEnabled(self, enabled: bool) -> None: ...
    @overload
    def setBorderColor(self, color: Union[PySide6.QtGui.QColor, PySide6.QtGui.QRgba64, Any, PySide6.QtCore.Qt.GlobalColor, str, int]) -> None: ...
    @overload
    def setBorderColor(self, r: float, g: float, b: float, a: float) -> None: ...
    @overload
    def setBorderColor(self, r: int, g: int, b: int, a: int) -> None: ...
    @overload
    def setBorderColor(self, r: int, g: int, b: int, a: int) -> None: ...
    def setComparisonFunction(self, function: PySide6.QtOpenGL.QOpenGLTexture.ComparisonFunction) -> None: ...
    def setComparisonMode(self, mode: PySide6.QtOpenGL.QOpenGLTexture.ComparisonMode) -> None: ...
    @overload
    def setCompressedData(self, dataSize: int, data: int, options: Optional[PySide6.QtOpenGL.QOpenGLPixelTransferOptions] = ...) -> None: ...
    @overload
    def setCompressedData(self, mipLevel: int, dataSize: int, data: int, options: Optional[PySide6.QtOpenGL.QOpenGLPixelTransferOptions] = ...) -> None: ...
    @overload
    def setCompressedData(self, mipLevel: int, layer: int, cubeFace: PySide6.QtOpenGL.QOpenGLTexture.CubeMapFace, dataSize: int, data: int, options: Optional[PySide6.QtOpenGL.QOpenGLPixelTransferOptions] = ...) -> None: ...
    @overload
    def setCompressedData(self, mipLevel: int, layer: int, dataSize: int, data: int, options: Optional[PySide6.QtOpenGL.QOpenGLPixelTransferOptions] = ...) -> None: ...
    @overload
    def setCompressedData(self, mipLevel: int, layer: int, layerCount: int, cubeFace: PySide6.QtOpenGL.QOpenGLTexture.CubeMapFace, dataSize: int, data: int, options: Optional[PySide6.QtOpenGL.QOpenGLPixelTransferOptions] = ...) -> None: ...
    @overload
    def setData(self, image: Union[PySide6.QtGui.QImage, str], genMipMaps: PySide6.QtOpenGL.QOpenGLTexture.MipMapGeneration = ...) -> None: ...
    @overload
    def setData(self, mipLevel: int, layer: int, cubeFace: PySide6.QtOpenGL.QOpenGLTexture.CubeMapFace, sourceFormat: PySide6.QtOpenGL.QOpenGLTexture.PixelFormat, sourceType: PySide6.QtOpenGL.QOpenGLTexture.PixelType, data: int, options: Optional[PySide6.QtOpenGL.QOpenGLPixelTransferOptions] = ...) -> None: ...
    @overload
    def setData(self, mipLevel: int, layer: int, layerCount: int, cubeFace: PySide6.QtOpenGL.QOpenGLTexture.CubeMapFace, sourceFormat: PySide6.QtOpenGL.QOpenGLTexture.PixelFormat, sourceType: PySide6.QtOpenGL.QOpenGLTexture.PixelType, data: int, options: Optional[PySide6.QtOpenGL.QOpenGLPixelTransferOptions] = ...) -> None: ...
    @overload
    def setData(self, mipLevel: int, layer: int, sourceFormat: PySide6.QtOpenGL.QOpenGLTexture.PixelFormat, sourceType: PySide6.QtOpenGL.QOpenGLTexture.PixelType, data: int, options: Optional[PySide6.QtOpenGL.QOpenGLPixelTransferOptions] = ...) -> None: ...
    @overload
    def setData(self, mipLevel: int, sourceFormat: PySide6.QtOpenGL.QOpenGLTexture.PixelFormat, sourceType: PySide6.QtOpenGL.QOpenGLTexture.PixelType, data: int, options: Optional[PySide6.QtOpenGL.QOpenGLPixelTransferOptions] = ...) -> None: ...
    @overload
    def setData(self, sourceFormat: PySide6.QtOpenGL.QOpenGLTexture.PixelFormat, sourceType: PySide6.QtOpenGL.QOpenGLTexture.PixelType, data: int, options: Optional[PySide6.QtOpenGL.QOpenGLPixelTransferOptions] = ...) -> None: ...
    @overload
    def setData(self, xOffset: int, yOffset: int, zOffset: int, width: int, height: int, depth: int, mipLevel: int, layer: int, cubeFace: PySide6.QtOpenGL.QOpenGLTexture.CubeMapFace, layerCount: int, sourceFormat: PySide6.QtOpenGL.QOpenGLTexture.PixelFormat, sourceType: PySide6.QtOpenGL.QOpenGLTexture.PixelType, data: int, options: Optional[PySide6.QtOpenGL.QOpenGLPixelTransferOptions] = ...) -> None: ...
    @overload
    def setData(self, xOffset: int, yOffset: int, zOffset: int, width: int, height: int, depth: int, mipLevel: int, layer: int, cubeFace: PySide6.QtOpenGL.QOpenGLTexture.CubeMapFace, sourceFormat: PySide6.QtOpenGL.QOpenGLTexture.PixelFormat, sourceType: PySide6.QtOpenGL.QOpenGLTexture.PixelType, data: int, options: Optional[PySide6.QtOpenGL.QOpenGLPixelTransferOptions] = ...) -> None: ...
    @overload
    def setData(self, xOffset: int, yOffset: int, zOffset: int, width: int, height: int, depth: int, mipLevel: int, layer: int, sourceFormat: PySide6.QtOpenGL.QOpenGLTexture.PixelFormat, sourceType: PySide6.QtOpenGL.QOpenGLTexture.PixelType, data: int, options: Optional[PySide6.QtOpenGL.QOpenGLPixelTransferOptions] = ...) -> None: ...
    @overload
    def setData(self, xOffset: int, yOffset: int, zOffset: int, width: int, height: int, depth: int, mipLevel: int, sourceFormat: PySide6.QtOpenGL.QOpenGLTexture.PixelFormat, sourceType: PySide6.QtOpenGL.QOpenGLTexture.PixelType, data: int, options: Optional[PySide6.QtOpenGL.QOpenGLPixelTransferOptions] = ...) -> None: ...
    @overload
    def setData(self, xOffset: int, yOffset: int, zOffset: int, width: int, height: int, depth: int, sourceFormat: PySide6.QtOpenGL.QOpenGLTexture.PixelFormat, sourceType: PySide6.QtOpenGL.QOpenGLTexture.PixelType, data: int, options: Optional[PySide6.QtOpenGL.QOpenGLPixelTransferOptions] = ...) -> None: ...
    def setDepthStencilMode(self, mode: PySide6.QtOpenGL.QOpenGLTexture.DepthStencilMode) -> None: ...
    def setFixedSamplePositions(self, fixed: bool) -> None: ...
    def setFormat(self, format: PySide6.QtOpenGL.QOpenGLTexture.TextureFormat) -> None: ...
    def setLayers(self, layers: int) -> None: ...
    def setLevelOfDetailRange(self, min: float, max: float) -> None: ...
    def setLevelofDetailBias(self, bias: float) -> None: ...
    def setMagnificationFilter(self, filter: PySide6.QtOpenGL.QOpenGLTexture.Filter) -> None: ...
    def setMaximumAnisotropy(self, anisotropy: float) -> None: ...
    def setMaximumLevelOfDetail(self, value: float) -> None: ...
    def setMinMagFilters(self, minificationFilter: PySide6.QtOpenGL.QOpenGLTexture.Filter, magnificationFilter: PySide6.QtOpenGL.QOpenGLTexture.Filter) -> None: ...
    def setMinificationFilter(self, filter: PySide6.QtOpenGL.QOpenGLTexture.Filter) -> None: ...
    def setMinimumLevelOfDetail(self, value: float) -> None: ...
    def setMipBaseLevel(self, baseLevel: int) -> None: ...
    def setMipLevelRange(self, baseLevel: int, maxLevel: int) -> None: ...
    def setMipLevels(self, levels: int) -> None: ...
    def setMipMaxLevel(self, maxLevel: int) -> None: ...
    def setSamples(self, samples: int) -> None: ...
    def setSize(self, width: int, height: int = ..., depth: int = ...) -> None: ...
    @overload
    def setSwizzleMask(self, component: PySide6.QtOpenGL.QOpenGLTexture.SwizzleComponent, value: PySide6.QtOpenGL.QOpenGLTexture.SwizzleValue) -> None: ...
    @overload
    def setSwizzleMask(self, r: PySide6.QtOpenGL.QOpenGLTexture.SwizzleValue, g: PySide6.QtOpenGL.QOpenGLTexture.SwizzleValue, b: PySide6.QtOpenGL.QOpenGLTexture.SwizzleValue, a: PySide6.QtOpenGL.QOpenGLTexture.SwizzleValue) -> None: ...
    @overload
    def setWrapMode(self, direction: PySide6.QtOpenGL.QOpenGLTexture.CoordinateDirection, mode: PySide6.QtOpenGL.QOpenGLTexture.WrapMode) -> None: ...
    @overload
    def setWrapMode(self, mode: PySide6.QtOpenGL.QOpenGLTexture.WrapMode) -> None: ...
    def swizzleMask(self, component: PySide6.QtOpenGL.QOpenGLTexture.SwizzleComponent) -> PySide6.QtOpenGL.QOpenGLTexture.SwizzleValue: ...
    def target(self) -> PySide6.QtOpenGL.QOpenGLTexture.Target: ...
    def textureId(self) -> int: ...
    def width(self) -> int: ...
    def wrapMode(self, direction: PySide6.QtOpenGL.QOpenGLTexture.CoordinateDirection) -> PySide6.QtOpenGL.QOpenGLTexture.WrapMode: ...


class QOpenGLTextureBlitter(Shiboken.Object):

    class Origin(enum.Enum):

        OriginBottomLeft         : QOpenGLTextureBlitter.Origin = ... # 0x0
        OriginTopLeft            : QOpenGLTextureBlitter.Origin = ... # 0x1


    def __init__(self) -> None: ...

    def bind(self, target: int = ...) -> None: ...
    @overload
    def blit(self, texture: int, targetTransform: Union[PySide6.QtGui.QMatrix4x4, PySide6.QtGui.QTransform], sourceOrigin: PySide6.QtOpenGL.QOpenGLTextureBlitter.Origin) -> None: ...
    @overload
    def blit(self, texture: int, targetTransform: Union[PySide6.QtGui.QMatrix4x4, PySide6.QtGui.QTransform], sourceTransform: PySide6.QtGui.QMatrix3x3) -> None: ...
    def create(self) -> bool: ...
    def destroy(self) -> None: ...
    def isCreated(self) -> bool: ...
    def release(self) -> None: ...
    def setOpacity(self, opacity: float) -> None: ...
    def setRedBlueSwizzle(self, swizzle: bool) -> None: ...
    @staticmethod
    def sourceTransform(subTexture: Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect], textureSize: PySide6.QtCore.QSize, origin: PySide6.QtOpenGL.QOpenGLTextureBlitter.Origin) -> PySide6.QtGui.QMatrix3x3: ...
    def supportsExternalOESTarget(self) -> bool: ...
    def supportsRectangleTarget(self) -> bool: ...
    @staticmethod
    def targetTransform(target: Union[PySide6.QtCore.QRectF, PySide6.QtCore.QRect], viewport: PySide6.QtCore.QRect) -> PySide6.QtGui.QMatrix4x4: ...


class QOpenGLVersionProfile(Shiboken.Object):

    @overload
    def __init__(self) -> None: ...
    @overload
    def __init__(self, format: Union[PySide6.QtGui.QSurfaceFormat, PySide6.QtGui.QSurfaceFormat.FormatOption]) -> None: ...
    @overload
    def __init__(self, other: PySide6.QtOpenGL.QOpenGLVersionProfile) -> None: ...

    @staticmethod
    def __copy__() -> None: ...
    def hasProfiles(self) -> bool: ...
    def isLegacyVersion(self) -> bool: ...
    def isValid(self) -> bool: ...
    def profile(self) -> PySide6.QtGui.QSurfaceFormat.OpenGLContextProfile: ...
    def setProfile(self, profile: PySide6.QtGui.QSurfaceFormat.OpenGLContextProfile) -> None: ...
    def setVersion(self, majorVersion: int, minorVersion: int) -> None: ...
    def version(self) -> Tuple[int, int]: ...


class QOpenGLVertexArrayObject(PySide6.QtCore.QObject):

    class Binder(Shiboken.Object):

        def __init__(self, v: PySide6.QtOpenGL.QOpenGLVertexArrayObject) -> None: ...

        def __enter__(self) -> PySide6.QtOpenGL.QOpenGLVertexArrayObject.Binder: ...
        def __exit__(self, arg__1: object, arg__2: object, arg__3: object) -> None: ...
        def rebind(self) -> None: ...
        def release(self) -> None: ...


    def __init__(self, parent: Optional[PySide6.QtCore.QObject] = ...) -> None: ...

    def bind(self) -> None: ...
    def create(self) -> bool: ...
    def destroy(self) -> None: ...
    def isCreated(self) -> bool: ...
    def objectId(self) -> int: ...
    def release(self) -> None: ...


class QOpenGLWindow(PySide6.QtGui.QPaintDeviceWindow):

    frameSwapped             : ClassVar[Signal] = ... # frameSwapped()

    class UpdateBehavior(enum.Enum):

        NoPartialUpdate          : QOpenGLWindow.UpdateBehavior = ... # 0x0
        PartialUpdateBlit        : QOpenGLWindow.UpdateBehavior = ... # 0x1
        PartialUpdateBlend       : QOpenGLWindow.UpdateBehavior = ... # 0x2


    @overload
    def __init__(self, shareContext: PySide6.QtGui.QOpenGLContext, updateBehavior: PySide6.QtOpenGL.QOpenGLWindow.UpdateBehavior = ..., parent: Optional[PySide6.QtGui.QWindow] = ...) -> None: ...
    @overload
    def __init__(self, updateBehavior: PySide6.QtOpenGL.QOpenGLWindow.UpdateBehavior = ..., parent: Optional[PySide6.QtGui.QWindow] = ...) -> None: ...

    def context(self) -> PySide6.QtGui.QOpenGLContext: ...
    def defaultFramebufferObject(self) -> int: ...
    def doneCurrent(self) -> None: ...
    def grabFramebuffer(self) -> PySide6.QtGui.QImage: ...
    def initializeGL(self) -> None: ...
    def isValid(self) -> bool: ...
    def makeCurrent(self) -> None: ...
    def metric(self, metric: PySide6.QtGui.QPaintDevice.PaintDeviceMetric) -> int: ...
    def paintEvent(self, event: PySide6.QtGui.QPaintEvent) -> None: ...
    def paintGL(self) -> None: ...
    def paintOverGL(self) -> None: ...
    def paintUnderGL(self) -> None: ...
    def redirected(self, arg__1: PySide6.QtCore.QPoint) -> PySide6.QtGui.QPaintDevice: ...
    def resizeEvent(self, event: PySide6.QtGui.QResizeEvent) -> None: ...
    def resizeGL(self, w: int, h: int) -> None: ...
    def shareContext(self) -> PySide6.QtGui.QOpenGLContext: ...
    def updateBehavior(self) -> PySide6.QtOpenGL.QOpenGLWindow.UpdateBehavior: ...


# eof
